/********************************************************************************
** Form generated from reading UI file 'texttospeechconfigurationui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTTOSPEECHCONFIGURATIONUI_H
#define UI_TEXTTOSPEECHCONFIGURATIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_texttospeechconfigurationui
{
public:
    QGridLayout *gridLayout;
    QGroupBox *qtspeechGroupBox;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *engineComboBox;
    QLabel *label_2;
    QComboBox *voiceComboBox;
    QGroupBox *alternativeGroupBox;
    QVBoxLayout *verticalLayout;
    QVBoxLayout *vboxLayout;
    QLabel *urlLabel;
    KUrlRequester *urlReq;
    QCheckBox *stdInButton;
    QVBoxLayout *vboxLayout1;
    QLabel *characterCodingLabel;
    KComboBox *characterCodingBox;

    void setupUi(QWidget *texttospeechconfigurationui)
    {
        if (texttospeechconfigurationui->objectName().isEmpty())
            texttospeechconfigurationui->setObjectName("texttospeechconfigurationui");
        texttospeechconfigurationui->resize(466, 222);
        gridLayout = new QGridLayout(texttospeechconfigurationui);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        qtspeechGroupBox = new QGroupBox(texttospeechconfigurationui);
        qtspeechGroupBox->setObjectName("qtspeechGroupBox");
        qtspeechGroupBox->setCheckable(true);
        formLayout = new QFormLayout(qtspeechGroupBox);
        formLayout->setObjectName("formLayout");
        label = new QLabel(qtspeechGroupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        engineComboBox = new QComboBox(qtspeechGroupBox);
        engineComboBox->setObjectName("engineComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(engineComboBox->sizePolicy().hasHeightForWidth());
        engineComboBox->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, engineComboBox);

        label_2 = new QLabel(qtspeechGroupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        voiceComboBox = new QComboBox(qtspeechGroupBox);
        voiceComboBox->setObjectName("voiceComboBox");
        sizePolicy.setHeightForWidth(voiceComboBox->sizePolicy().hasHeightForWidth());
        voiceComboBox->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, voiceComboBox);


        gridLayout->addWidget(qtspeechGroupBox, 0, 0, 4, 1);

        alternativeGroupBox = new QGroupBox(texttospeechconfigurationui);
        alternativeGroupBox->setObjectName("alternativeGroupBox");
        alternativeGroupBox->setEnabled(false);
        verticalLayout = new QVBoxLayout(alternativeGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        urlLabel = new QLabel(alternativeGroupBox);
        urlLabel->setObjectName("urlLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(urlLabel->sizePolicy().hasHeightForWidth());
        urlLabel->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(urlLabel);

        urlReq = new KUrlRequester(alternativeGroupBox);
        urlReq->setObjectName("urlReq");
        sizePolicy1.setHeightForWidth(urlReq->sizePolicy().hasHeightForWidth());
        urlReq->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(urlReq);


        verticalLayout->addLayout(vboxLayout);

        stdInButton = new QCheckBox(alternativeGroupBox);
        stdInButton->setObjectName("stdInButton");

        verticalLayout->addWidget(stdInButton);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        characterCodingLabel = new QLabel(alternativeGroupBox);
        characterCodingLabel->setObjectName("characterCodingLabel");
        sizePolicy1.setHeightForWidth(characterCodingLabel->sizePolicy().hasHeightForWidth());
        characterCodingLabel->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(characterCodingLabel);

        characterCodingBox = new KComboBox(alternativeGroupBox);
        characterCodingBox->setObjectName("characterCodingBox");

        vboxLayout1->addWidget(characterCodingBox);


        verticalLayout->addLayout(vboxLayout1);


        gridLayout->addWidget(alternativeGroupBox, 0, 1, 4, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(engineComboBox);
        label_2->setBuddy(voiceComboBox);
        urlLabel->setBuddy(urlReq);
        characterCodingLabel->setBuddy(characterCodingBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(texttospeechconfigurationui);

        QMetaObject::connectSlotsByName(texttospeechconfigurationui);
    } // setupUi

    void retranslateUi(QWidget *texttospeechconfigurationui)
    {
        texttospeechconfigurationui->setWindowTitle(tr2i18n("Text-to-Speech", nullptr));
        qtspeechGroupBox->setTitle(tr2i18n("&Use default speech system", nullptr));
        label->setText(tr2i18n("&Engine:", nullptr));
        label_2->setText(tr2i18n("&Voice:", nullptr));
        alternativeGroupBox->setTitle(tr2i18n("Alternative", nullptr));
#if QT_CONFIG(whatsthis)
        urlLabel->setWhatsThis(tr2i18n("This field specifies both the command used for speaking texts and its parameters. KMouth knows the following placeholders:\n"
"%t -- the text that should be spoken\n"
"%f -- the name of a file containing the text\n"
"%l -- the language code\n"
"%% -- a percent sign", nullptr));
#endif // QT_CONFIG(whatsthis)
        urlLabel->setText(tr2i18n("Command for speaking &texts:", nullptr));
#if QT_CONFIG(whatsthis)
        urlReq->setWhatsThis(tr2i18n("This field specifies both the command used for speaking texts and its parameters. KMouth knows the following placeholders:\n"
"%t -- the text that should be spoken\n"
"%f -- the name of a file containing the text\n"
"%l -- the language code\n"
"%% -- a percent sign", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        stdInButton->setWhatsThis(tr2i18n("This check box specifies whether the text is sent as standard input to the speech synthesizer.", nullptr));
#endif // QT_CONFIG(whatsthis)
        stdInButton->setText(tr2i18n("Send the data as standard &input", nullptr));
#if QT_CONFIG(whatsthis)
        characterCodingLabel->setWhatsThis(tr2i18n("This combo box specifies which character encoding is used for passing the text.", nullptr));
#endif // QT_CONFIG(whatsthis)
        characterCodingLabel->setText(tr2i18n("Character encodin&g:", nullptr));
#if QT_CONFIG(whatsthis)
        characterCodingBox->setWhatsThis(tr2i18n("This combo box specifies which character encoding is used for passing the text.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class texttospeechconfigurationui: public Ui_texttospeechconfigurationui {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEXTTOSPEECHCONFIGURATIONUI_H

