/********************************************************************************
** Form generated from reading UI file 'preferencesui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCESUI_H
#define UI_PREFERENCESUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_PreferencesUI
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *speakLabel;
    KComboBox *speakCombo;
    QVBoxLayout *vboxLayout2;
    QLabel *closeLabel;
    KComboBox *closeCombo;

    void setupUi(QWidget *PreferencesUI)
    {
        if (PreferencesUI->objectName().isEmpty())
            PreferencesUI->setObjectName("PreferencesUI");
        PreferencesUI->resize(339, 148);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(PreferencesUI->sizePolicy().hasHeightForWidth());
        PreferencesUI->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(PreferencesUI);
#ifndef UI_Q_OS_MACOS
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MACOS
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MACOS
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        speakLabel = new QLabel(PreferencesUI);
        speakLabel->setObjectName("speakLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(speakLabel->sizePolicy().hasHeightForWidth());
        speakLabel->setSizePolicy(sizePolicy1);

        vboxLayout1->addWidget(speakLabel);

        speakCombo = new KComboBox(PreferencesUI);
        speakCombo->addItem(QString());
        speakCombo->addItem(QString());
        speakCombo->setObjectName("speakCombo");

        vboxLayout1->addWidget(speakCombo);


        vboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
#ifndef UI_Q_OS_MACOS
        vboxLayout2->setSpacing(6);
#endif
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout2->setObjectName("vboxLayout2");
        closeLabel = new QLabel(PreferencesUI);
        closeLabel->setObjectName("closeLabel");
        sizePolicy1.setHeightForWidth(closeLabel->sizePolicy().hasHeightForWidth());
        closeLabel->setSizePolicy(sizePolicy1);

        vboxLayout2->addWidget(closeLabel);

        closeCombo = new KComboBox(PreferencesUI);
        closeCombo->addItem(QString());
        closeCombo->addItem(QString());
        closeCombo->addItem(QString());
        closeCombo->setObjectName("closeCombo");

        vboxLayout2->addWidget(closeCombo);


        vboxLayout->addLayout(vboxLayout2);

#if QT_CONFIG(shortcut)
        speakLabel->setBuddy(speakCombo);
        closeLabel->setBuddy(closeCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PreferencesUI);

        QMetaObject::connectSlotsByName(PreferencesUI);
    } // setupUi

    void retranslateUi(QWidget *PreferencesUI)
    {
        PreferencesUI->setWindowTitle(tr2i18n("Preferences", nullptr));
#if QT_CONFIG(whatsthis)
        speakLabel->setWhatsThis(tr2i18n("This combo box specifies whether selected phrases of the phrase book are immediately spoken or just inserted into the edit field.", nullptr));
#endif // QT_CONFIG(whatsthis)
        speakLabel->setText(tr2i18n("&Selection of phrases in the phrase book:", nullptr));
        speakCombo->setItemText(0, tr2i18n("Speak Immediately", nullptr));
        speakCombo->setItemText(1, tr2i18n("Insert Into Edit Field", nullptr));

#if QT_CONFIG(whatsthis)
        speakCombo->setWhatsThis(tr2i18n("This combo box specifies whether selected phrases of the phrase book are immediately spoken or just inserted into the edit field.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        closeLabel->setWhatsThis(tr2i18n("This combo box specifies whether the phrase book is automatically saved when the edit window is closed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        closeLabel->setText(tr2i18n("Closing the phrase &book edit window:", nullptr));
        closeCombo->setItemText(0, tr2i18n("Save Phrase Book", nullptr));
        closeCombo->setItemText(1, tr2i18n("Discard Changes", nullptr));
        closeCombo->setItemText(2, tr2i18n("Ask Whether to Save", nullptr));

#if QT_CONFIG(whatsthis)
        closeCombo->setWhatsThis(tr2i18n("This combo box specifies whether the phrase book is automatically saved when the edit window is closed.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class PreferencesUI: public Ui_PreferencesUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCESUI_H

