/********************************************************************************
** Form generated from reading UI file 'kdedocsourceui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KDEDOCSOURCEUI_H
#define UI_KDEDOCSOURCEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klanguagebutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KDEDocSourceUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *spellCheckBox;
    KUrlRequester *ooDictURL;
    KLanguageButton *languageButton;
    QLabel *languageLabel;

    void setupUi(QWidget *KDEDocSourceUI)
    {
        if (KDEDocSourceUI->objectName().isEmpty())
            KDEDocSourceUI->setObjectName("KDEDocSourceUI");
        KDEDocSourceUI->resize(272, 118);
        gridLayout = new QGridLayout(KDEDocSourceUI);
#ifndef UI_Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        spellCheckBox = new QCheckBox(KDEDocSourceUI);
        spellCheckBox->setObjectName("spellCheckBox");
        spellCheckBox->setChecked(false);

        gridLayout->addWidget(spellCheckBox, 1, 0, 1, 2);

        ooDictURL = new KUrlRequester(KDEDocSourceUI);
        ooDictURL->setObjectName("ooDictURL");
        ooDictURL->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ooDictURL->sizePolicy().hasHeightForWidth());
        ooDictURL->setSizePolicy(sizePolicy);

        gridLayout->addWidget(ooDictURL, 2, 1, 1, 1);

        languageButton = new KLanguageButton(KDEDocSourceUI);
        languageButton->setObjectName("languageButton");
        languageButton->setFocusPolicy(Qt::WheelFocus);

        gridLayout->addWidget(languageButton, 0, 1, 1, 1);

        languageLabel = new QLabel(KDEDocSourceUI);
        languageLabel->setObjectName("languageLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(languageLabel->sizePolicy().hasHeightForWidth());
        languageLabel->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(languageLabel, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        languageLabel->setBuddy(languageButton);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KDEDocSourceUI);
        QObject::connect(spellCheckBox, SIGNAL(toggled(bool)), ooDictURL, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(KDEDocSourceUI);
    } // setupUi

    void retranslateUi(QWidget *KDEDocSourceUI)
    {
#if QT_CONFIG(whatsthis)
        spellCheckBox->setWhatsThis(tr2i18n("If you select this check box the words from the KDE documentation are spell-checked before they are inserted into the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        spellCheckBox->setText(tr2i18n("C&ompare to OpenOffice.org dictionary:", nullptr));
#if QT_CONFIG(whatsthis)
        ooDictURL->setWhatsThis(tr2i18n("With this input field you select the OpenOffice.org directory that will be used to spellcheck the words of the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        languageLabel->setWhatsThis(tr2i18n("With this combo box you select which of the installed languages is used for creating the new dictionary. KMouth will only parse documentation files of this language.", nullptr));
#endif // QT_CONFIG(whatsthis)
        languageLabel->setText(tr2i18n("&Language:", nullptr));
        (void)KDEDocSourceUI;
    } // retranslateUi

};

namespace Ui {
    class KDEDocSourceUI: public Ui_KDEDocSourceUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KDEDOCSOURCEUI_H

