/****************************************************************************
** Meta object code from reading C++ file 'phraselist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kmouth-26.07.80/phraselist.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'phraselist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PhraseListE_t {};
} // unnamed namespace

template <> constexpr inline auto PhraseList::qt_create_metaobjectdata<qt_meta_tag_ZN10PhraseListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PhraseList",
        "speak",
        "",
        "cut",
        "copy",
        "paste",
        "insert",
        "s",
        "speakListSelection",
        "removeListSelection",
        "cutListSelection",
        "copyListSelection",
        "save",
        "open",
        "QUrl",
        "url",
        "selectAllEntries",
        "deselectAllEntries",
        "configureCompletion",
        "saveWordCompletion",
        "saveCompletionOptions",
        "readCompletionOptions",
        "lineEntered",
        "phrase",
        "contextMenuRequested",
        "QPoint",
        "pos",
        "textChanged",
        "selectionChanged",
        "keyPressEvent",
        "QKeyEvent*",
        "e",
        "configureCompletionCombo",
        "list"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'speak'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'speakListSelection'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeListSelection'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cutListSelection'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyListSelection'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open'
        QtMocHelpers::SlotData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'selectAllEntries'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deselectAllEntries'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureCompletion'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveWordCompletion'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveCompletionOptions'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readCompletionOptions'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lineEntered'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'contextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'textChanged'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'keyPressEvent'
        QtMocHelpers::SlotData<void(QKeyEvent *)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'configureCompletionCombo'
        QtMocHelpers::SlotData<void(const QStringList &)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QStringList, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PhraseList, qt_meta_tag_ZN10PhraseListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PhraseList::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhraseListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhraseListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PhraseListE_t>.metaTypes,
    nullptr
} };

void PhraseList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PhraseList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->speak(); break;
        case 1: _t->cut(); break;
        case 2: _t->copy(); break;
        case 3: _t->paste(); break;
        case 4: _t->insert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->speakListSelection(); break;
        case 6: _t->removeListSelection(); break;
        case 7: _t->cutListSelection(); break;
        case 8: _t->copyListSelection(); break;
        case 9: _t->save(); break;
        case 10: _t->open(); break;
        case 11: _t->open((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->selectAllEntries(); break;
        case 13: _t->deselectAllEntries(); break;
        case 14: _t->configureCompletion(); break;
        case 15: _t->saveWordCompletion(); break;
        case 16: _t->saveCompletionOptions(); break;
        case 17: _t->readCompletionOptions(); break;
        case 18: _t->lineEntered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->contextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 20: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->selectionChanged(); break;
        case 22: _t->keyPressEvent((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 23: _t->configureCompletionCombo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PhraseList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PhraseList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PhraseListE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PhraseList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
