/********************************************************************************
** Form generated from reading UI file 'wordcompletionui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WORDCOMPLETIONUI_H
#define UI_WORDCOMPLETIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klanguagebutton.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_WordCompletionUI
{
public:
    QGridLayout *gridLayout;
    QGroupBox *selectedDictionaryDetails;
    QGridLayout *gridLayout1;
    KLanguageButton *languageButton;
    QLabel *languageLabel;
    QLabel *dictionaryNameLabel;
    KLineEdit *dictionaryName;
    QVBoxLayout *vboxLayout;
    QPushButton *addButton;
    QPushButton *deleteButton;
    QPushButton *moveUpButton;
    QPushButton *moveDownButton;
    QPushButton *exportButton;
    QSpacerItem *spacerItem;
    QTableView *dictionaryView;

    void setupUi(QWidget *WordCompletionUI)
    {
        if (WordCompletionUI->objectName().isEmpty())
            WordCompletionUI->setObjectName("WordCompletionUI");
        WordCompletionUI->resize(400, 300);
        gridLayout = new QGridLayout(WordCompletionUI);
#ifndef UI_Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MACOS
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        selectedDictionaryDetails = new QGroupBox(WordCompletionUI);
        selectedDictionaryDetails->setObjectName("selectedDictionaryDetails");
        selectedDictionaryDetails->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(selectedDictionaryDetails->sizePolicy().hasHeightForWidth());
        selectedDictionaryDetails->setSizePolicy(sizePolicy);
        gridLayout1 = new QGridLayout(selectedDictionaryDetails);
#ifndef UI_Q_OS_MACOS
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MACOS
        gridLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout1->setObjectName("gridLayout1");
        languageButton = new KLanguageButton(selectedDictionaryDetails);
        languageButton->setObjectName("languageButton");

        gridLayout1->addWidget(languageButton, 1, 1, 1, 1);

        languageLabel = new QLabel(selectedDictionaryDetails);
        languageLabel->setObjectName("languageLabel");

        gridLayout1->addWidget(languageLabel, 1, 0, 1, 1);

        dictionaryNameLabel = new QLabel(selectedDictionaryDetails);
        dictionaryNameLabel->setObjectName("dictionaryNameLabel");
        dictionaryNameLabel->setEnabled(false);

        gridLayout1->addWidget(dictionaryNameLabel, 0, 0, 1, 1);

        dictionaryName = new KLineEdit(selectedDictionaryDetails);
        dictionaryName->setObjectName("dictionaryName");

        gridLayout1->addWidget(dictionaryName, 0, 1, 1, 1);


        gridLayout->addWidget(selectedDictionaryDetails, 1, 0, 1, 1);

        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MACOS
        vboxLayout->setSpacing(6);
#endif
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        addButton = new QPushButton(WordCompletionUI);
        addButton->setObjectName("addButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(addButton->sizePolicy().hasHeightForWidth());
        addButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(addButton);

        deleteButton = new QPushButton(WordCompletionUI);
        deleteButton->setObjectName("deleteButton");
        deleteButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(deleteButton->sizePolicy().hasHeightForWidth());
        deleteButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(deleteButton);

        moveUpButton = new QPushButton(WordCompletionUI);
        moveUpButton->setObjectName("moveUpButton");
        moveUpButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(moveUpButton->sizePolicy().hasHeightForWidth());
        moveUpButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(moveUpButton);

        moveDownButton = new QPushButton(WordCompletionUI);
        moveDownButton->setObjectName("moveDownButton");
        moveDownButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(moveDownButton->sizePolicy().hasHeightForWidth());
        moveDownButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(moveDownButton);

        exportButton = new QPushButton(WordCompletionUI);
        exportButton->setObjectName("exportButton");
        exportButton->setEnabled(false);
        sizePolicy1.setHeightForWidth(exportButton->sizePolicy().hasHeightForWidth());
        exportButton->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(exportButton);

        spacerItem = new QSpacerItem(20, 240, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        gridLayout->addLayout(vboxLayout, 0, 1, 2, 1);

        dictionaryView = new QTableView(WordCompletionUI);
        dictionaryView->setObjectName("dictionaryView");
        dictionaryView->setSelectionMode(QAbstractItemView::SingleSelection);
        dictionaryView->setSelectionBehavior(QAbstractItemView::SelectRows);
        dictionaryView->setProperty("allColumnsShowFocus", QVariant(true));
        dictionaryView->horizontalHeader()->setVisible(true);
        dictionaryView->horizontalHeader()->setStretchLastSection(true);
        dictionaryView->verticalHeader()->setVisible(false);

        gridLayout->addWidget(dictionaryView, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        languageLabel->setBuddy(languageButton);
        dictionaryNameLabel->setBuddy(dictionaryName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(addButton, deleteButton);
        QWidget::setTabOrder(deleteButton, moveUpButton);
        QWidget::setTabOrder(moveUpButton, moveDownButton);
        QWidget::setTabOrder(moveDownButton, exportButton);
        QWidget::setTabOrder(exportButton, selectedDictionaryDetails);

        retranslateUi(WordCompletionUI);

        QMetaObject::connectSlotsByName(WordCompletionUI);
    } // setupUi

    void retranslateUi(QWidget *WordCompletionUI)
    {
        selectedDictionaryDetails->setTitle(tr2i18n("&Selected Dictionary", nullptr));
#if QT_CONFIG(whatsthis)
        languageLabel->setWhatsThis(tr2i18n("With this combo box you select the language associated with the selected dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        languageLabel->setText(tr2i18n("&Language:", nullptr));
#if QT_CONFIG(whatsthis)
        dictionaryNameLabel->setWhatsThis(tr2i18n("With this input field you specify the name of the selected dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        dictionaryNameLabel->setText(tr2i18n("&Name:", nullptr));
#if QT_CONFIG(whatsthis)
        dictionaryName->setWhatsThis(tr2i18n("With this input field you specify the name of the selected dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        addButton->setWhatsThis(tr2i18n("With this button you can add a new dictionary to the list of available dictionaries.", nullptr));
#endif // QT_CONFIG(whatsthis)
        addButton->setText(tr2i18n("Add D&ictionary...", nullptr));
#if QT_CONFIG(whatsthis)
        deleteButton->setWhatsThis(tr2i18n("With this button you delete the selected dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteButton->setText(tr2i18n("&Delete Dictionary", nullptr));
#if QT_CONFIG(whatsthis)
        moveUpButton->setWhatsThis(tr2i18n("With this button you move the selected dictionary up.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveUpButton->setText(tr2i18n("Move &Up", nullptr));
#if QT_CONFIG(whatsthis)
        moveDownButton->setWhatsThis(tr2i18n("With this button you move the selected dictionary down.", nullptr));
#endif // QT_CONFIG(whatsthis)
        moveDownButton->setText(tr2i18n("&Move Down", nullptr));
#if QT_CONFIG(whatsthis)
        exportButton->setWhatsThis(tr2i18n("With this button you export the selected dictionary to a file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        exportButton->setText(tr2i18n("&Export Dictionary...", nullptr));
#if QT_CONFIG(whatsthis)
        dictionaryView->setWhatsThis(tr2i18n("This list contains all available dictionaries for the word completion. KMouth will display a combo box next to the edit field in the main window if this list contains more than one dictionary. You can use this combo box in order to select the dictionary that actually gets used for the word completion.", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)WordCompletionUI;
    } // retranslateUi

};

namespace Ui {
    class WordCompletionUI: public Ui_WordCompletionUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WORDCOMPLETIONUI_H

