/********************************************************************************
** Form generated from reading UI file 'phrasebookdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PHRASEBOOKDIALOG_H
#define UI_PHRASEBOOKDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kkeysequencewidget.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_PhraseBookDialog
{
public:
    QGridLayout *gridLayout;
    QGroupBox *phrasebox;
    QGridLayout *gridLayout1;
    KKeySequenceWidget *keyButton;
    KLineEdit *lineEdit;
    QRadioButton *noKey;
    QRadioButton *customKey;
    QLabel *shortcutLabel;
    QLabel *textLabel;
    QTreeView *treeView;

    void setupUi(QWidget *PhraseBookDialog)
    {
        if (PhraseBookDialog->objectName().isEmpty())
            PhraseBookDialog->setObjectName("PhraseBookDialog");
        PhraseBookDialog->resize(564, 393);
        gridLayout = new QGridLayout(PhraseBookDialog);
#ifndef UI_Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        phrasebox = new QGroupBox(PhraseBookDialog);
        phrasebox->setObjectName("phrasebox");
        gridLayout1 = new QGridLayout(phrasebox);
#ifndef UI_Q_OS_MACOS
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName("gridLayout1");
        keyButton = new KKeySequenceWidget(phrasebox);
        keyButton->setObjectName("keyButton");

        gridLayout1->addWidget(keyButton, 3, 2, 1, 1);

        lineEdit = new KLineEdit(phrasebox);
        lineEdit->setObjectName("lineEdit");

        gridLayout1->addWidget(lineEdit, 1, 0, 1, 3);

        noKey = new QRadioButton(phrasebox);
        noKey->setObjectName("noKey");

        gridLayout1->addWidget(noKey, 3, 0, 1, 1);

        customKey = new QRadioButton(phrasebox);
        customKey->setObjectName("customKey");

        gridLayout1->addWidget(customKey, 3, 1, 1, 1);

        shortcutLabel = new QLabel(phrasebox);
        shortcutLabel->setObjectName("shortcutLabel");

        gridLayout1->addWidget(shortcutLabel, 2, 0, 1, 3);

        textLabel = new QLabel(phrasebox);
        textLabel->setObjectName("textLabel");

        gridLayout1->addWidget(textLabel, 0, 0, 1, 3);


        gridLayout->addWidget(phrasebox, 1, 0, 1, 1);

        treeView = new QTreeView(PhraseBookDialog);
        treeView->setObjectName("treeView");
        treeView->setContextMenuPolicy(Qt::CustomContextMenu);
        treeView->setDragEnabled(true);
        treeView->setDragDropMode(QAbstractItemView::InternalMove);
        treeView->setDefaultDropAction(Qt::MoveAction);
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setUniformRowHeights(true);
        treeView->setAllColumnsShowFocus(true);
        treeView->header()->setDefaultSectionSize(300);

        gridLayout->addWidget(treeView, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel->setBuddy(lineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PhraseBookDialog);

        QMetaObject::connectSlotsByName(PhraseBookDialog);
    } // setupUi

    void retranslateUi(QWidget *PhraseBookDialog)
    {
        PhraseBookDialog->setWindowTitle(tr2i18n("Phrase Book", nullptr));
        phrasebox->setTitle(tr2i18n("&Currently Selected Phrase or Phrase Book", nullptr));
#if QT_CONFIG(whatsthis)
        keyButton->setWhatsThis(tr2i18n("By clicking on this button you can select the keyboard shortcut associated with the selected phrase.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        lineEdit->setWhatsThis(tr2i18n("With this line edit you define the name of a sub-phrasebook or the contents of a phrase.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        noKey->setWhatsThis(tr2i18n("If you select this option then the selected phrase will not be reachable by a keyboard shortcut.", nullptr));
#endif // QT_CONFIG(whatsthis)
        noKey->setText(tr2i18n("&None", nullptr));
#if QT_CONFIG(whatsthis)
        customKey->setWhatsThis(tr2i18n("If you select this option then the selected phrase will be reachable by a keyboard shortcut. You can change the shortcut with the button next to this option.", nullptr));
#endif // QT_CONFIG(whatsthis)
        customKey->setText(tr2i18n("C&ustom", nullptr));
        shortcutLabel->setText(tr2i18n("Shortcut for the phrase:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel->setWhatsThis(tr2i18n("With this line edit you define the name of a sub-phrasebook or the contents of a phrase.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel->setText(tr2i18n("Text of the &phrase:", nullptr));
#if QT_CONFIG(whatsthis)
        treeView->setWhatsThis(tr2i18n("This list contains the current phrase book in a tree structure. You can select and modify individual phrases and sub phrase books", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class PhraseBookDialog: public Ui_PhraseBookDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PHRASEBOOKDIALOG_H

