/********************************************************************************
** Form generated from reading UI file 'creationsourcedetailsui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATIONSOURCEDETAILSUI_H
#define UI_CREATIONSOURCEDETAILSUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klanguagebutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CreationSourceDetailsUI
{
public:
    QGridLayout *gridLayout;
    QCheckBox *spellCheckBox;
    QLabel *encodingLabel;
    QLabel *urlLabel;
    KUrlRequester *url;
    KComboBox *encodingCombo;
    KUrlRequester *ooDictURL;
    KLanguageButton *languageButton;
    QLabel *languageLabel;

    void setupUi(QWidget *CreationSourceDetailsUI)
    {
        if (CreationSourceDetailsUI->objectName().isEmpty())
            CreationSourceDetailsUI->setObjectName("CreationSourceDetailsUI");
        CreationSourceDetailsUI->resize(421, 189);
        gridLayout = new QGridLayout(CreationSourceDetailsUI);
#ifndef UI_Q_OS_MACOS
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        spellCheckBox = new QCheckBox(CreationSourceDetailsUI);
        spellCheckBox->setObjectName("spellCheckBox");
        spellCheckBox->setChecked(false);

        gridLayout->addWidget(spellCheckBox, 3, 0, 1, 2);

        encodingLabel = new QLabel(CreationSourceDetailsUI);
        encodingLabel->setObjectName("encodingLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(encodingLabel->sizePolicy().hasHeightForWidth());
        encodingLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(encodingLabel, 1, 0, 1, 1);

        urlLabel = new QLabel(CreationSourceDetailsUI);
        urlLabel->setObjectName("urlLabel");
        sizePolicy.setHeightForWidth(urlLabel->sizePolicy().hasHeightForWidth());
        urlLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(urlLabel, 0, 0, 1, 1);

        url = new KUrlRequester(CreationSourceDetailsUI);
        url->setObjectName("url");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(url->sizePolicy().hasHeightForWidth());
        url->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(url, 0, 1, 1, 1);

        encodingCombo = new KComboBox(CreationSourceDetailsUI);
        encodingCombo->setObjectName("encodingCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(encodingCombo->sizePolicy().hasHeightForWidth());
        encodingCombo->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(encodingCombo, 1, 1, 1, 1);

        ooDictURL = new KUrlRequester(CreationSourceDetailsUI);
        ooDictURL->setObjectName("ooDictURL");
        ooDictURL->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(1);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(ooDictURL->sizePolicy().hasHeightForWidth());
        ooDictURL->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(ooDictURL, 4, 1, 1, 1);

        languageButton = new KLanguageButton(CreationSourceDetailsUI);
        languageButton->setObjectName("languageButton");

        gridLayout->addWidget(languageButton, 2, 1, 1, 1);

        languageLabel = new QLabel(CreationSourceDetailsUI);
        languageLabel->setObjectName("languageLabel");
        sizePolicy.setHeightForWidth(languageLabel->sizePolicy().hasHeightForWidth());
        languageLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(languageLabel, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        encodingLabel->setBuddy(encodingCombo);
        urlLabel->setBuddy(url);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CreationSourceDetailsUI);
        QObject::connect(spellCheckBox, SIGNAL(toggled(bool)), ooDictURL, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CreationSourceDetailsUI);
    } // setupUi

    void retranslateUi(QWidget *CreationSourceDetailsUI)
    {
#if QT_CONFIG(whatsthis)
        spellCheckBox->setWhatsThis(tr2i18n("If you select this check box the words are spell-checked before they are inserted into the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        spellCheckBox->setText(tr2i18n("C&ompare to OpenOffice.org dictionary:", nullptr));
#if QT_CONFIG(whatsthis)
        encodingLabel->setWhatsThis(tr2i18n("With this combo box you select the character encoding used to load text files. This combo box is not used for XML files or for dictionary files.", nullptr));
#endif // QT_CONFIG(whatsthis)
        encodingLabel->setText(tr2i18n("Character &encoding:", nullptr));
#if QT_CONFIG(whatsthis)
        urlLabel->setWhatsThis(tr2i18n("With this input field you specify which file you want to load for creating the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        urlLabel->setText(tr2i18n("&Filename:", nullptr));
#if QT_CONFIG(whatsthis)
        url->setWhatsThis(tr2i18n("With this input field you specify which file you want to load for creating the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        encodingCombo->setWhatsThis(tr2i18n("With this combo box you select the character encoding used to load text files. This combo box is not used for XML files or for dictionary files.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        ooDictURL->setWhatsThis(tr2i18n("With this input field you select the OpenOffice.org directory that will be used to spellcheck the words of the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        languageLabel->setWhatsThis(tr2i18n("With this combo box you decide which language should be associated with the new dictionary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        languageLabel->setText(tr2i18n("&Language:", nullptr));
        (void)CreationSourceDetailsUI;
    } // retranslateUi

};

namespace Ui {
    class CreationSourceDetailsUI: public Ui_CreationSourceDetailsUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREATIONSOURCEDETAILSUI_H

