/********************************************************************************
** Form generated from reading UI file 'creationsourceui.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATIONSOURCEUI_H
#define UI_CREATIONSOURCEUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CreationSourceUI
{
public:
    QGridLayout *gridLayout;
    QRadioButton *createButton;
    QRadioButton *mergeButton;
    QRadioButton *fileButton;
    QRadioButton *kdeDocButton;
    QRadioButton *directoryButton;
    QSpacerItem *spacer1;
    QRadioButton *emptyButton;

    void setupUi(QWidget *CreationSourceUI)
    {
        if (CreationSourceUI->objectName().isEmpty())
            CreationSourceUI->setObjectName("CreationSourceUI");
        CreationSourceUI->resize(318, 223);
        gridLayout = new QGridLayout(CreationSourceUI);
        gridLayout->setObjectName("gridLayout");
        createButton = new QRadioButton(CreationSourceUI);
        createButton->setObjectName("createButton");
        createButton->setChecked(true);

        gridLayout->addWidget(createButton, 0, 0, 1, 2);

        mergeButton = new QRadioButton(CreationSourceUI);
        mergeButton->setObjectName("mergeButton");

        gridLayout->addWidget(mergeButton, 4, 0, 1, 2);

        fileButton = new QRadioButton(CreationSourceUI);
        fileButton->setObjectName("fileButton");
        fileButton->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileButton->sizePolicy().hasHeightForWidth());
        fileButton->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileButton, 2, 1, 1, 1);

        kdeDocButton = new QRadioButton(CreationSourceUI);
        kdeDocButton->setObjectName("kdeDocButton");
        kdeDocButton->setEnabled(true);
        sizePolicy.setHeightForWidth(kdeDocButton->sizePolicy().hasHeightForWidth());
        kdeDocButton->setSizePolicy(sizePolicy);
        kdeDocButton->setChecked(true);

        gridLayout->addWidget(kdeDocButton, 1, 1, 1, 1);

        directoryButton = new QRadioButton(CreationSourceUI);
        directoryButton->setObjectName("directoryButton");
        directoryButton->setEnabled(true);
        sizePolicy.setHeightForWidth(directoryButton->sizePolicy().hasHeightForWidth());
        directoryButton->setSizePolicy(sizePolicy);

        gridLayout->addWidget(directoryButton, 3, 1, 1, 1);

        spacer1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(spacer1, 1, 0, 3, 1);

        emptyButton = new QRadioButton(CreationSourceUI);
        emptyButton->setObjectName("emptyButton");

        gridLayout->addWidget(emptyButton, 5, 0, 1, 2);


        retranslateUi(CreationSourceUI);
        QObject::connect(createButton, &QRadioButton::toggled, kdeDocButton, &QRadioButton::setEnabled);
        QObject::connect(createButton, &QRadioButton::toggled, fileButton, &QRadioButton::setEnabled);
        QObject::connect(createButton, &QRadioButton::toggled, directoryButton, &QRadioButton::setEnabled);

        QMetaObject::connectSlotsByName(CreationSourceUI);
    } // setupUi

    void retranslateUi(QWidget *CreationSourceUI)
    {
        createButton->setText(tr2i18n("C&reate new dictionary:", nullptr));
#if QT_CONFIG(whatsthis)
        createButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a new dictionary is created by either loading a dictionary file or by counting the individual words in a text.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        mergeButton->setText(tr2i18n("&Merge dictionaries", nullptr));
#if QT_CONFIG(whatsthis)
        mergeButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a new dictionary is created by merging existing dictionaries.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        fileButton->setText(tr2i18n("From &file", nullptr));
#if QT_CONFIG(whatsthis)
        fileButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a new dictionary is created by loading a file. You may either select an XML file, a standard text file or a file containing a word completion dictionary. If you select a standard text file or an XML file the frequentness of the individual words is detected by simply counting the occurrences of each word.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        kdeDocButton->setText(tr2i18n("From &KDE documentation", nullptr));
#if QT_CONFIG(whatsthis)
        kdeDocButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a new dictionary is created by parsing the KDE documentation. The frequentness of the individual words is detect by simply counting the occurrences of each word.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        directoryButton->setText(tr2i18n("From f&older", nullptr));
#if QT_CONFIG(whatsthis)
        directoryButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a new dictionary is created by loading all files in a folder and its subdirectories.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        emptyButton->setText(tr2i18n("Create an &empty wordlist", nullptr));
#if QT_CONFIG(whatsthis)
        emptyButton->setProperty("whatsThis", QVariant(tr2i18n("If you select this box a blank dictionary without any entries is created. As KMouth automatically adds newly typed words to the dictionaries it will learn your vocabulary with the time.", nullptr)));
#endif // QT_CONFIG(whatsthis)
        (void)CreationSourceUI;
    } // retranslateUi

};

namespace Ui {
    class CreationSourceUI: public Ui_CreationSourceUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREATIONSOURCEUI_H

